@@ -33,11 +33,6 @@
 #' everything works well, you will get a message that says you can return to R. If not,
 #' try again in a few minutes to make sure your app had its settings updated properly.
 #'
-#' Note that the authentication process will NOT work correctly in RStudio. As an
-#' alternative, create your token in R from the command line interface or the R
-#' application, save it as a file, and then open it up from RStudio.
-#' 
-#'
 #' @author
 #' Pablo Barbera \email{pablo.barbera@@nyu.edu}
 #' @seealso \code{\link{getUsers}}, \code{\link{getPost}}, \code{\link{searchFacebook}}
@@ -93,13 +88,26 @@ fbOAuth <- function(app_id, app_secret, extended_permissions=TRUE)
 			collapse="")
 	}
 	else { scope <- NULL}
-	facebook_token <- oauth2.0_token(facebook, myapp,
-	  scope=scope, type = "application/x-www-form-urlencoded")
-	fb_oauth <- sign_oauth2.0(facebook_token$access_token)
-	## testing that authentication was successful. 
-	if (GET("https://graph.facebook.com/me", config=fb_oauth)$status==200){
-		message("Authentication successful.")
+
+	## before httr 0.3
+	if (packageVersion('httr')$minor < 3){
+		facebook_token <- oauth2.0_token(facebook, myapp,
+		  scope=scope, type = "application/x-www-form-urlencoded")
+		fb_oauth <- sign_oauth2.0(facebook_token$access_token) 
+		if (GET("https://graph.facebook.com/me", config=fb_oauth)$status==200){
+			message("Authentication successful.")
+		}
 	}
+
+	## with httr 0.3
+	if (packageVersion('httr')$minor >= 3){
+		fb_oauth <- oauth2.0_token(facebook, myapp,
+		  scope=scope, type = "application/x-www-form-urlencoded", cache=FALSE)	
+		if (GET("https://graph.facebook.com/me", config(token=fb_oauth))$status==200){
+	      	message("Authentication successful.")
+	  	}	
+	}
+
 	return(fb_oauth)
 }
 
